# loading snakefile variables
args = commandArgs(trailingOnly=TRUE)

input = args[1]
outdir = dirname(args[2])
templatedir = args[3]
index_html = args[4]
# read the knit_meta() output generated by knit.R
# which is a must for interactive plots (js libraries)

knitmeta_filename = sub(input, pattern = ".md$",
    replacement = ".knitmeta.RDS")
knitmeta = list()
if(file.exists(knitmeta_filename)){
    knitmeta = readRDS(knitmeta_filename)
}

source(file.path(templatedir, "outputLook.R"))
# expand css path
cssind  <- which(optionsRender$rmarkdown$pandoc$args=="--css")+1
csspath <- optionsRender$rmarkdown$pandoc$args[cssind]
# remove the redundant 'template/' prefix
csspath = sub(x = csspath, pattern = '^template/', replacement = '')
csspath <- file.path(templatedir, csspath)
optionsRender$rmarkdown$pandoc$args[cssind] = csspath
# add path for regular markdown figures
optionsRender$rmarkdown$pandoc$args =
	c(optionsRender$rmarkdown$pandoc$args,
		paste0("--resource-path=", getwd(), ":",
			file.path(getwd(), dirname(input))))
# custom title for each html doc
optionsRender$rmarkdown$pandoc$args =
	c(optionsRender$rmarkdown$pandoc$args,
		paste0("--metadata=pagetitle:",
        	sub("\\.md$", "", basename(input))))

# generate the html file
suppressWarnings(suppressMessages({
rmarkdown::render(input,
	output_format = optionsRender$rmarkdown,
	output_dir = outdir,
	output_file = file.path(outdir,
		sub(x=basename(input), pattern=".md$", replacement=".html")),
	quiet = TRUE, knit_meta = knitmeta)
}))

html_outfile = sub(pattern = ".md$", replacement = ".html",
	file.path(outdir, basename(input)))
html_text = readLines(html_outfile)

writeLines(text=gsub(pattern="(navbar-brand.*)index.html",
    replacement=paste0("\\1", index_html),
        x=html_text), con=html_outfile)
